@@ -34,7 +34,7 @@ static char dkim_h_id[] = "@(#)$Id: dkim.h,v 1.36.2.1 2010/10/27 21:43:08 cm-msk
 **  	pp == patch number
 */
 
-#define	OPENDKIM_LIB_VERSION	0x02050200
+#define	OPENDKIM_LIB_VERSION	0x02060700
 
 #ifdef __STDC__
 # ifndef __P
@@ -288,6 +288,8 @@ typedef int dkim_opts_t;
 #define DKIM_LIBFLAGS_BADSIGHANDLES	0x0400
 #define DKIM_LIBFLAGS_VERIFYONE		0x0800
 #define DKIM_LIBFLAGS_STRICTHDRS	0x1000
+#define DKIM_LIBFLAGS_REPORTBADADSP	0x2000
+#define DKIM_LIBFLAGS_DROPSIGNER	0x4000
 
 #define	DKIM_LIBFLAGS_DEFAULT		DKIM_LIBFLAGS_NONE
 
@@ -975,19 +977,6 @@ extern DKIM_STAT dkim_set_user_context __P((DKIM *dkim, void *ctx));
 
 extern void *dkim_get_user_context __P((DKIM *dkim));
 
-/*
-**  DKIM_GET_MSGDATE -- retrieve value extracted from the Date: header
-**
-**  Parameters:
-**  	dkim -- DKIM handle
-**
-**  Return value:
-**  	time_t representing the value in the Date: header of the message,
-**  	or 0 if no such header was found or the value in it was unusable
-*/
-
-extern uint64_t dkim_get_msgdate __P((DKIM *dkim));
-
 /*
 **  DKIM_GETMODE -- return the mode (signing, verifying, etc.) of a handle
 **
